Crate kcr_charts_helm_k8s_io

Crate kcr_charts_helm_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the charts.helm.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

charts.helm.k8s.io/v1alpha1

  • SnykMonitor

Modules

v1alpha1